package cn.com.infosec.jce.provider;

import cn.com.infosec.crypto.AsymmetricBlockCipher;
import cn.com.infosec.crypto.Digest;
import cn.com.infosec.crypto.digests.MD5Digest;
import cn.com.infosec.crypto.digests.RIPEMD160Digest;
import cn.com.infosec.crypto.digests.SHA1Digest;
import cn.com.infosec.crypto.engines.RSABlindedEngine;
import cn.com.infosec.crypto.params.RSAKeyParameters;
import cn.com.infosec.crypto.signers.ISO9796d2Signer;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.SignatureException;
import java.security.SignatureSpi;
import java.security.interfaces.RSAPrivateKey;
import java.security.interfaces.RSAPublicKey;
import java.security.spec.AlgorithmParameterSpec;

public class JDKISOSignature extends SignatureSpi {
   private ISO9796d2Signer signer;

   protected JDKISOSignature(Digest digest, AsymmetricBlockCipher cipher) {
      JDKISOSignature var10000 = this;
      super();
      ISO9796d2Signer var3;
      var3 = new ISO9796d2Signer.<init>(cipher, digest, true);
      var10000.signer = var3;
   }

   protected void engineInitVerify(PublicKey publicKey) {
      JDKISOSignature var10000 = this;
      RSAKeyParameters var2 = RSAUtil.generatePublicKeyParameter((RSAPublicKey)publicKey);
      var10000.signer.init(false, var2);
   }

   protected void engineInitSign(PrivateKey privateKey) {
      JDKISOSignature var10000 = this;
      RSAKeyParameters var2 = RSAUtil.generatePrivateKeyParameter((RSAPrivateKey)privateKey);
      var10000.signer.init(true, var2);
   }

   protected void engineUpdate(byte b) {
      this.signer.update(b);
   }

   protected void engineUpdate(byte[] b, int off, int len) {
      this.signer.update(b, off, len);
   }

   protected byte[] engineSign() {
      try {
         return this.signer.generateSignature();
      } catch (Exception var1) {
         throw new SignatureException(var1.toString());
      }
   }

   protected boolean engineVerify(byte[] sigBytes) {
      return this.signer.verifySignature(sigBytes);
   }

   protected void engineSetParameter(AlgorithmParameterSpec params) {
      throw new UnsupportedOperationException("engineSetParameter unsupported");
   }

   /** @deprecated */
   protected void engineSetParameter(String param, Object value) {
      throw new UnsupportedOperationException("engineSetParameter unsupported");
   }

   /** @deprecated */
   protected Object engineGetParameter(String param) {
      throw new UnsupportedOperationException("engineSetParameter unsupported");
   }

   public static class MD5WithRSAEncryption extends JDKISOSignature {
      public MD5WithRSAEncryption() {
         MD5WithRSAEncryption var10000 = this;
         MD5Digest var2;
         var2 = new MD5Digest.<init>();
         RSABlindedEngine var1;
         var1 = new RSABlindedEngine.<init>();
         var10000.<init>(var2, var1);
      }
   }

   public static class RIPEMD160WithRSAEncryption extends JDKISOSignature {
      public RIPEMD160WithRSAEncryption() {
         RIPEMD160WithRSAEncryption var10000 = this;
         RIPEMD160Digest var2;
         var2 = new RIPEMD160Digest.<init>();
         RSABlindedEngine var1;
         var1 = new RSABlindedEngine.<init>();
         var10000.<init>(var2, var1);
      }
   }

   public static class SHA1WithRSAEncryption extends JDKISOSignature {
      public SHA1WithRSAEncryption() {
         SHA1WithRSAEncryption var10000 = this;
         SHA1Digest var2;
         var2 = new SHA1Digest.<init>();
         RSABlindedEngine var1;
         var1 = new RSABlindedEngine.<init>();
         var10000.<init>(var2, var1);
      }
   }
}
